Index: trunk/quest-core-testgeneration/src/main/java/de/ugoe/cs/quest/testgeneration/DrawFromAllSequencesGenerator.java
===================================================================
--- trunk/quest-core-testgeneration/src/main/java/de/ugoe/cs/quest/testgeneration/DrawFromAllSequencesGenerator.java	(revision 655)
+++ trunk/quest-core-testgeneration/src/main/java/de/ugoe/cs/quest/testgeneration/DrawFromAllSequencesGenerator.java	(revision 766)
@@ -1,5 +1,4 @@
 package de.ugoe.cs.quest.testgeneration;
 
-import java.security.InvalidParameterException;
 import java.util.ArrayList;
 import java.util.Collection;
@@ -73,5 +72,5 @@
      * <li>minLength must be less than or equal to maxLength
      * </ul>
      * If one of these conditions is violated an {@link InvalidParameterException} is thrown.
      * </p>
      * 
@@ -97,14 +96,14 @@
         // check validity of the parameters
         if (numSequences < 1) {
-            throw new InvalidParameterException("number of sequences must be at least 1 but is " +
+            throw new IllegalArgumentException("number of sequences must be at least 1 but is " +
                 numSequences);
         }
         if (maxLength < 1) {
-            throw new InvalidParameterException(
+            throw new IllegalArgumentException(
                                                 "maximal allowed length of test cases must be at least 1 but is " +
                                                     maxLength);
         }
         if (minLength > maxLength) {
-            throw new InvalidParameterException(
+            throw new IllegalArgumentException(
                                                 "minimal allowed length of test cases must be less than or equal to the maximal allowed length (min length: " +
                                                     minLength + " ; max length: " + maxLength + ")");
@@ -128,5 +127,5 @@
     public Collection<List<Event>> generateTestSuite(IStochasticProcess model) {
         if (model == null) {
-            throw new InvalidParameterException("model must not be null!");
+            throw new IllegalArgumentException("model must not be null!");
         }
 
@@ -73,5 +72,5 @@
      * <li>minLength must be less than or equal to maxLength
      * </ul>
-     * If one of these conditions is violated an {@link InvalidParameterException} is thrown.
+     * If one of these conditions is violated an {@link IllegalArgumentException} is thrown.
      * </p>
      * 
Index: trunk/quest-core-testgeneration/src/main/java/de/ugoe/cs/quest/testgeneration/HybridGenerator.java
===================================================================
--- trunk/quest-core-testgeneration/src/main/java/de/ugoe/cs/quest/testgeneration/HybridGenerator.java	(revision 655)
+++ trunk/quest-core-testgeneration/src/main/java/de/ugoe/cs/quest/testgeneration/HybridGenerator.java	(revision 766)
@@ -1,5 +1,4 @@
 package de.ugoe.cs.quest.testgeneration;
 
-import java.security.InvalidParameterException;
 import java.util.ArrayList;
 import java.util.Collection;
@@ -61,5 +60,5 @@
      * <li>length must be at least 1
      * </ul>
      * If one of these conditions is violated an {@link InvalidParameterException} is thrown.
      * </p>
      * 
@@ -77,9 +76,9 @@
         // check validity of the parameters
         if (numSequences < 1) {
-            throw new InvalidParameterException("number of sequences must be at least 1 but is " +
+            throw new IllegalArgumentException("number of sequences must be at least 1 but is " +
                 numSequences);
         }
         if (length < 1) {
-            throw new InvalidParameterException("length of test cases must be at least 1 but is " +
+            throw new IllegalArgumentException("length of test cases must be at least 1 but is " +
                 length);
         }
@@ -102,5 +101,5 @@
     public Collection<List<Event>> generateTestSuite(IStochasticProcess model) {
         if (model == null) {
-            throw new InvalidParameterException("model must not be null!");
+            throw new IllegalArgumentException("model must not be null!");
         }
 
@@ -61,5 +60,5 @@
      * <li>length must be at least 1
      * </ul>
-     * If one of these conditions is violated an {@link InvalidParameterException} is thrown.
+     * If one of these conditions is violated an {@link IllegalArgumentException} is thrown.
      * </p>
      * 
Index: trunk/quest-core-testgeneration/src/main/java/de/ugoe/cs/quest/testgeneration/RandomWalkGenerator.java
===================================================================
--- trunk/quest-core-testgeneration/src/main/java/de/ugoe/cs/quest/testgeneration/RandomWalkGenerator.java	(revision 655)
+++ trunk/quest-core-testgeneration/src/main/java/de/ugoe/cs/quest/testgeneration/RandomWalkGenerator.java	(revision 766)
@@ -1,5 +1,4 @@
 package de.ugoe.cs.quest.testgeneration;
 
-import java.security.InvalidParameterException;
 import java.util.Collection;
 import java.util.HashSet;
@@ -75,5 +74,5 @@
      * <li>maxIter must be greater than or equal to numSequences
      * </ul>
      * If one of these conditions is violated an {@link InvalidParameterException} is thrown.
      * </p>
      * 
@@ -99,19 +98,19 @@
         // check validity of the parameters
         if (numSequences < 1) {
-            throw new InvalidParameterException("number of sequences must be at least 1 but is " +
+            throw new IllegalArgumentException("number of sequences must be at least 1 but is " +
                 numSequences);
         }
         if (maxLength < 1) {
-            throw new InvalidParameterException(
+            throw new IllegalArgumentException(
                                                 "maximal allowed length of test cases must be at least 1 but is " +
                                                     maxLength);
         }
         if (minLength > maxLength) {
-            throw new InvalidParameterException(
+            throw new IllegalArgumentException(
                                                 "minimal allowed length of test cases must be less than or equal to the maximal allowed length (min length: " +
                                                     minLength + " ; max length: " + maxLength + ")");
         }
         if (maxIter < numSequences) {
-            throw new InvalidParameterException(
+            throw new IllegalArgumentException(
                                                 "maximal number of iterations must greater than or equal to the number of sequences (number of sequences: " +
                                                     numSequences +
@@ -138,5 +137,5 @@
     public Collection<List<Event>> generateTestSuite(IStochasticProcess model) {
         if (model == null) {
-            throw new InvalidParameterException("model must not be null!");
+            throw new IllegalArgumentException("model must not be null!");
         }
 
@@ -75,5 +74,5 @@
      * <li>maxIter must be greater than or equal to numSequences
      * </ul>
-     * If one of these conditions is violated an {@link InvalidParameterException} is thrown.
+     * If one of these conditions is violated an {@link IllegalArgumentException} is thrown.
      * </p>
      * 
